DelayedCommands

Struct DelayedCommands 

pub struct DelayedCommands<'w, 's> { /* private fields */ }
A wrapper over Commands that stores CommandQueues to be applied with given delays.

When dropped, the queues are spawned into the world as new entities with DelayedCommandQueue components, and then checked by the check_delayed_command_queues system.

Implementations

Source

impl<'w, 's> DelayedCommands<'w, 's>

pub fn duration(&mut self, duration: Duration) -> Commands<'w, '_>

Return a Commands whose commands will be delayed by duration.

pub fn secs(&mut self, secs: f32) -> Commands<'w, '_>

Return a Commands whose commands will be delayed by secs seconds.